# -*- coding: utf-8 -*-
"""
NeuronPy
~~~~~~~~

A library of Python interfaces and utilities for the
NEURON simulator and analysis of neural data.
"""

__version__ = '0.1.5'
__author__ = 'Thomas McTavish'
__email__ = 'Thomas.McTavish@yale.edu'
__url__ = 'http://bitbucket.org/tommctavish/neuronpy/'
__license__ = 'MIT License'
__docformat__ = 'restructuredtext'
__all__ = [ 'graphics', 'math', 'nrnobjects', 'util']
